@@ -52,6 +52,7 @@ from constants_and_vars import STATS
 import unicode_csv
 from datetime import datetime
 import unicodedata
+import re
 
 def callback_model(self, model, field, line):
     """Model of the calback signature.
@@ -412,7 +413,7 @@ def city_cedex(res=None, cedex_code=False):
 
     return _city_cedex
 
-def zfill(*args):
+def zfill(*args, **kwargs):
     """Return a zfilled string.
 
     .. note::
@@ -425,11 +426,11 @@ def zfill(*args):
     
     """
     def _zfill(self, model ,field, value, line):
-        return value.zfill(*args)
+        return value.zfill(*args, **kwargs)
 
     return _zfill
 
-def upper(*args):
+def upper(*args, **kwargs):
     """Return a uppered string.
 
     .. note::
@@ -442,11 +443,11 @@ def upper(*args):
     
     """
     def _upper(self, model ,field, value, line):
-        return value.upper(*args)
+        return value.upper(*args, **kwargs)
 
     return _upper
 
-def capitalize(*args):
+def capitalize(*args, **kwargs):
     """Return a capitalized string.
 
     .. note::
@@ -459,11 +460,11 @@ def capitalize(*args):
     
     """
     def _capitalize(self, model ,field, value, line):
-        return value.capitalize(*args)
+        return value.capitalize(*args, **kwargs)
 
     return _capitalize
 
-def strip(*args):
+def strip(*args, **kwargs):
     """Return a stripped string.
 
     .. note::
@@ -476,8 +477,103 @@ def strip(*args):
     
     """
     def _strip(self, model ,field, value, line):
-        return value.strip(*args)
+        return value.strip(*args, **kwargs)
 
     return _strip
 
+def get_phones(type, prefix='+33'):
+    """Returns numbers contained in the columns values. Numbers must be in a 
+    french form such as `0123456789` or '33123456789' (No matters for spaces).
+    Any other numbers must not be in the columns values.
+
+    ..note:
+
+        Example of a complex working string:
+
+        "The number of Mr SMITH is 0123456789, his wife 33 234 567 894, and their son 06 24 568495"
+
+        will returns independently of what type but with prefix `(+33)`:
+        dict = {   
+            'phone': ['(+33) 1 23 45 67 89', '(+33) 2 34 56 78 94'],
+            'mobile': ['(+33) 6 24 56 84 95'], 
+            'all': ['(+33) 1 23 45 67 89', '(+33) 2 34 56 78 94', '(+33) 6 24 56 84 95'], 
+            'value': "The number of Mr SMITH is 02XXXXXXXX, his wife 33 2XX XXXXXX, and their son 06 XX XX XX XX XX"
+        }
+
+
+    
+    >>> 'phone':  Column([3, 4], get_phones('phone', prefix='+33'))
+    >>> 'mobile': Column([3, 4], get_phones('mobile', prefix='+33'))
+    >>> 'phone': Column([3, 4], get_phones('all', prefix='+33'))
+    
+    :param type: The format to returns
+    :type type: str
+    :param prefix: The prefix to insert
+    :type prefix: str
+    :returns: str (prefix X XX XX XX XX / prefix X XX XX XX XX ...)
+
+    """
+    assert type
+    if type not in ('phone', 'mobile', 'all', 'dict'):
+        raise Exception('`type` is incorrect. Valid values are `phone`, `mobile`, `all`')
+
+    def _get_phones(self, model, field, value, line):
+        res = {'phone': [], 'mobile': [], 'all': [], 'value': value}
+
+        # On ne garde que les caractères numériques
+        string = re.sub(u'[^0-9]', u'', value)
+        stop = False
+        i = 0
+        while not stop:
+            i += 1
+            # Chaine vide donc arrêt (Cas initial ou après traitement sans numéros)
+            if not string:
+                stop = True
+                continue
+
+            # Traitement du premier numéro - suppression du prefix
+            if string.startswith(u'0'):
+                string = string[1:]
+            elif string.startswith(u'33'):
+                string = string[2:]
+            else:
+                string = string[1:]
+                # Next loop
+                continue
+            
+            # Le numéro est-il complet (cas de fin de chaine)
+            if len(string) < 9:
+                # Next loop
+                continue
+            
+            # Isolement du numéro 
+            phone = string[:9]
+
+            # On le découpe en paire à l'exception du premier numéro 
+            tel_list = [phone[0], phone[1:3], phone[3:5], phone[5:7], phone[7:9]]
+
+            # Cas du téléphone portable
+            if tel_list[0] == '6':
+                res['mobile'].append((u'%s %s' % (prefix, u' '.join(tel_list))))
+                res['all'].append((u'%s %s' % (prefix, u' '.join(tel_list))))
+            # Autre cas
+            else:
+                res['phone'].append((u'%s %s' % (prefix, u' '.join(tel_list))))
+                res['all'].append((u'%s %s' % (prefix, u' '.join(tel_list))))
+
+            # Next loop
+            string = string[9:]
+
+        if type is 'dict':
+            return res
+
+        phones = res[type]
+        if len(phones) > 1:
+            result = ' / '.join(phones)
+        elif len(phones) == 1:
+            result = phones[0]
+         
+        return result
+
+    return _get_phones
 
